@@ -11,27 +11,32 @@ warnings.filterwarnings("ignore")
 
 def a_distinct(url, target_directory, lst_distinct_column):
     def write(bytes1):
-        df = pl.read_csv(bytes1)
+        df = pl_read_csv(bytes1)
         df = df.distinct(subset=lst_distinct_column)
-        bytesio = BytesIO()
-        df.to_csv(bytesio)
-        filename = os.path.basename(url)
-        filename = filename[:filename.find('.')]
-        path = f'{target_directory}{filename}.csv.gz'
-        with gzip.open(path, 'wb') as f:
-            f.write(bytesio.getvalue())
-        return url
+        return bytesio_to_gzip(df, url, target_directory)
 
-    return requests_get(write, url, target_directory)
+    return requests_get_write(target_directory, url, write)
 
 
 def it_distinct(lst_url, target_directory, lst_distinct_column):
     return it_mp_f(a_distinct, [tuple([url, target_directory, lst_distinct_column]) for url in lst_url])
 
 
+def bytesio_to_gzip(df, url, target_directory):
+    bytesio, filename = prepare_bytesio_filename(df, url)
+    path = f'{target_directory}{filename}.csv.gz'
+    write_gzip(bytesio, path)
+    return url
+
+
+def pl_read_csv(bytes1):
+    df = pl.read_csv(bytes1, infer_schema_length=20000)
+    return df
+
+
 def a_filter(url, target_directory, lst_distinct_column, lst_column_match=[], sort_column=''):
     def write(bytes1):
-        df = pl.read_csv(bytes1)
+        df = pl_read_csv(bytes1)
         condition = ''
         for lst_col_val in lst_column_match:
             condition += f"""(pl.col('{lst_col_val[0]}')=='{lst_col_val[1]}') | """
@@ -40,16 +45,18 @@ def a_filter(url, target_directory, lst_distinct_column, lst_column_match=[], so
         df = df.distinct(subset=lst_distinct_column)
         if sort_column:
             df = df.sort(sort_column)
-        bytesio = BytesIO()
-        df.to_csv(bytesio)
-        filename = os.path.basename(url)
-        filename = filename[:filename.find('.')]
-        path = f'{target_directory}{filename}.csv.gz'
-        with gzip.open(path, 'wb') as f:
-            f.write(bytesio.getvalue())
+        bytesio_to_gzip(df, url, target_directory)
         return url
 
-    return requests_get(write, url, target_directory)
+    return requests_get_write(target_directory, url, write)
+
+
+def requests_get_write(target_directory, url, f_write):
+    try:
+        requests_get(f_write, url, target_directory)
+    except Exception as e:
+        print(f'cameo_claw.py,requests_get_write,Exception:{e, url}')
+    return url
 
 
 def it_filter(lst_url, target_directory, lst_distinct_column, dic_column_match, sort_column):
@@ -66,16 +73,24 @@ def a_download(url, target_directory):
             f.write(bytes1)
         return url
 
-    return requests_get(write, url, target_directory)
+    return requests_get_write(target_directory, url, write)
 
 
 def it_download(lst_url, target_directory):
     return it_mp_f(a_download, [tuple([url, target_directory]) for url in lst_url])
 
 
+def prepare_bytesio_filename(df, url):
+    bytesio = BytesIO()
+    df.to_csv(bytesio)
+    filename = os.path.basename(url)
+    filename = filename[:filename.find('.')]
+    return bytesio, filename
+
+
 def a_group(url, target_directory, lst_distinct_column, lst_group_by_column):
     def write(bytes1):
-        df = pl.read_csv(bytes1)
+        df = pl_read_csv(bytes1)
         df = df.distinct(subset=lst_distinct_column)
         g = df.groupby(lst_group_by_column)
         for df in g:
@@ -83,16 +98,17 @@ def a_group(url, target_directory, lst_distinct_column, lst_group_by_column):
                 map(lambda column:
                     str(df.row(0)[df.find_idx_by_name(column)]).replace('_', '-'),
                     lst_group_by_column)))
-            bytesio = BytesIO()
-            df.to_csv(bytesio)
-            filename = os.path.basename(url)
-            filename = filename[:filename.find('.')]
+            bytesio, filename = prepare_bytesio_filename(df, url)
             path = f'{target_directory}{filename}{filename_tail}.csv.gz'
-            with gzip.open(path, 'wb') as f:
-                f.write(bytesio.getvalue())
+            write_gzip(bytesio, path)
         return url
 
-    return requests_get(write, url, target_directory)
+    return requests_get_write(target_directory, url, write)
+
+
+def write_gzip(bytesio, path):
+    with gzip.open(path, 'wb') as f:
+        f.write(bytesio.getvalue())
 
 
 def it_group(lst_url, target_directory, lst_distinct_column, lst_group_by_column):
